@@ -1,5 +1,5 @@
-from datetime import datetime, timedelta
-import dateutil.relativedelta
+from datetime import datetime, timedelta, date
+from dateutil.relativedelta import relativedelta
 import time
 import pandas as pd
 from sqlalchemy import create_engine
@@ -120,6 +120,16 @@ class hora:
       else:
          return datetime.strptime(yesterday,"%Y-%m-%d")
 
+   def mesesAtras(self,mesesAtras,asString=True):
+      hoy = date.today()
+      fromx = hoy - relativedelta(months=mesesAtras)
+      fromx = fromx.strftime("%Y-%m-01")
+      tox = hoy - relativedelta(months=(mesesAtras-1))
+      tox = tox.strftime("%Y-%m-01")
+      if(asString):
+         return {"fromx":fromx, "tox":tox}
+      else:
+         return {"fromx":datetime.strptime(fromx,"%Y-%m-%d"), "tox":datetime.strptime(tox,"%Y-%m-%d")}
 hora=hora()
 
 class out:
